# ClientInjection

Configuration specific to injected client javascript. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**enabled** | **bool** | if client injection is enabled | [optional] 
**version** | **str, none_type** | The version of the injection script. When omitted, the latest version will be used. | [optional] 
**login_config** | [**LoginInjection**](LoginInjection.md) |  | [optional] 
**debug** | **bool** | Enable debug mode of javascript  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


